@@ -24,5 +24,5 @@ class BookingAssistantFlowEvent:
 			sqs_service = SqsService()
 			return sqs_service.send(app_config.BOOKING_ASSISTANT_FLOW_QUEUE, json.dumps(event), app_config.BOOKING_ASSISTANT_DELAY_SECONDS)
 		except Exception as e:
-			logger.error(f"failed to send BookingAssistantFlowNotification message: {e}")
-			logger.error(f"BookingAssistantFlowNotification message: {event}")
+			logger.error(f"failed to send BookingAssistantFlowEvent message: {e}")
+			logger.error(f"BookingAssistantFlowEvent message: {event}")
